@@ -11,7 +11,7 @@ EXAMPLES::
     sage: A.<x,y> = MultivariatePolynomialAlgebra(QQ); A
     The Multivariate polynomial algebra on x over The Multivariate polynomial algebra on y over Rational Field
     sage: A.an_element()
-    y[0]*x[1, 2, 3] + y[0]*x[0, 0, 0] + 2*y[0]*x[1, 0, 0] + 3*y[0]*x[0, 1, 0]
+    y[0]*x[0, 0, 0] + 3*y[0]*x[0, 1, 0] + 2*y[0]*x[1, 0, 0] + y[0]*x[1, 2, 3]
 
 ``x`` and ``y`` correspond to the monomial basis on the two sets of variables::
 
@@ -20,9 +20,9 @@ EXAMPLES::
     sage: y
     The Multivariate polynomial algebra on y over Rational Field on the monomial basis
     sage: x.an_element()
-    y[0]*x[1, 2, 3] + y[0]*x[0, 0, 0] + 2*y[0]*x[1, 0, 0] + 3*y[0]*x[0, 1, 0]
+    y[0]*x[0, 0, 0] + 3*y[0]*x[0, 1, 0] + 2*y[0]*x[1, 0, 0] + y[0]*x[1, 2, 3]
     sage: y.an_element()
-    y[1, 2, 3] + y[0, 0, 0] + 2*y[1, 0, 0] + 3*y[0, 1, 0]
+    y[0, 0, 0] + 3*y[0, 1, 0] + 2*y[1, 0, 0] + y[1, 2, 3]
 
 By default, all actions are done on the ``x`` variable set::
 
@@ -43,7 +43,7 @@ You can change the bases of the ``x`` polynomial by the usual coercion system::
     sage: Schub = A.schubert_basis(); Schub
     The Multivariate polynomial algebra on x over The Multivariate polynomial algebra on y over Rational Field on the Schubert basis of type A
     sage: Schub(A.an_element())
-    y[0]*Yx[0, 0, 0] + 3*y[0]*Yx[0, 1, 0] + (-y[0])*Yx[1, 0, 0] + y[0]*Yx[1, 2, 3] + (-y[0])*Yx[2, 1, 3] + (-y[0])*Yx[1, 3, 2] + y[0]*Yx[3, 1, 2] + y[0]*Yx[2, 3, 1] + (-y[0])*Yx[3, 2, 1] + y[0]*Yx[4, 1, 1]
+    y[0]*Yx[0, 0, 0] + 3*y[0]*Yx[0, 1, 0] + (-y[0])*Yx[1, 0, 0] + y[0]*Yx[1, 2, 3] + (-y[0])*Yx[1, 3, 2] + (-y[0])*Yx[2, 1, 3] + y[0]*Yx[2, 3, 1] + y[0]*Yx[3, 1, 2] + (-y[0])*Yx[3, 2, 1] + y[0]*Yx[4, 1, 1]
 
 You can also change the base for the ``y``::
 
@@ -52,7 +52,7 @@ You can also change the base for the ``y``::
     sage: pol = y[1,2,3] * x[2,2,4]; pol
     (y[1,2,3])*x[2, 2, 4]
     sage: pol.change_coeffs_bases(YSchub)
-    (Yy[1,2,3]-Yy[2,1,3]-Yy[1,3,2]+Yy[3,1,2]+Yy[2,3,1]-Yy[3,2,1]+Yy[4,1,1])*x[2, 2, 4]
+    (Yy[1,2,3]-Yy[1,3,2]-Yy[2,1,3]+Yy[2,3,1]+Yy[3,1,2]-Yy[3,2,1]+Yy[4,1,1])*x[2, 2, 4]
 
 
 Also, you can obtain the ring where the roles of `x` and `y` are exchanged::
@@ -60,7 +60,7 @@ Also, you can obtain the ring where the roles of `x` and `y` are exchanged::
     sage: A2 =  A.inversed_ring(); A2
     The Multivariate polynomial algebra on y over The Multivariate polynomial algebra on x over Rational Field
     sage: A2.an_element()
-    x[0]*y[1, 2, 3] + x[0]*y[0, 0, 0] + 2*x[0]*y[1, 0, 0] + 3*x[0]*y[0, 1, 0]
+    x[0]*y[0, 0, 0] + 3*x[0]*y[0, 1, 0] + 2*x[0]*y[1, 0, 0] + x[0]*y[1, 2, 3]
 
 There is a coercion between ``A`` and ``A2``::
 
@@ -79,7 +79,7 @@ doesn't look for a parent where the coercion could be made::
     ...
     TypeError: unsupported operand parent(s) for +: 'The Multivariate polynomial algebra on x over The Multivariate polynomial algebra on y over Rational Field with 3 variables on the monomial basis' and 'The Multivariate polynomial algebra on y over The Multivariate polynomial algebra on x over Rational Field with 3 variables on the monomial basis'
     sage: A2(A.an_element()) + A2.an_element()
-    x[0]*y[1, 2, 3] + (x[1,2,3]+2*x[0,0,0]+2*x[1,0,0]+3*x[0,1,0])*y[0, 0, 0] + 2*x[0]*y[1, 0, 0] + 3*x[0]*y[0, 1, 0]
+    (2*x[0,0,0]+3*x[0,1,0]+2*x[1,0,0]+x[1,2,3])*y[0, 0, 0] + 3*x[0]*y[0, 1, 0] + 2*x[0]*y[1, 0, 0] + x[0]*y[1, 2, 3]
 
 Some special bases have been implemented for double polynomials::
 
@@ -89,13 +89,13 @@ Some special bases have been implemented for double polynomials::
     sage: DSchub[0,1]
     y[0]*YY[0, 1]
     sage: DSchub[0,1].expand()
-    y[0]*xA[1, 0] + y[0]*xA[0, 1] + (-yA[0,1]-yA[1,0])*xA[0, 0]
+    (-yA[0,1]-yA[1,0])*xA[0, 0] + y[0]*xA[0, 1] + y[0]*xA[1, 0]
     sage: DSchub[0,1]^2
-    y[0]*YY[0, 2] + y[0]*YY[1, 1] + (-yA[0,1,0]+yA[0,0,1])*YY[0, 1]
+    (yA[0,0,1]-yA[0,1,0])*YY[0, 1] + y[0]*YY[0, 2] + y[0]*YY[1, 1]
     sage: DSchub(x[0,1])
-    y[0]*YY[0, 1] + (-y[0])*YY[1, 0] + (yA[0,1])*YY[0, 0]
+    (yA[0,1])*YY[0, 0] + y[0]*YY[0, 1] + (-y[0])*YY[1, 0]
     sage: DSchub(y[0,1]*x[0,1])
-     (y[0,1])*YY[0, 1] + (-y[0,1])*YY[1, 0] + (yA[0,2])*YY[0, 0]
+     (yA[0,2])*YY[0, 0] + (y[0,1])*YY[0, 1] + (-y[0,1])*YY[1, 0]
     sage: DSchub(y[0,1])
     (y[0,1])*YY[0, 0]
     sage: DGroth = A.double_grothendieck_basis()
@@ -104,7 +104,7 @@ Some special bases have been implemented for double polynomials::
     sage: DGroth[0,1]
     y[0]*GG[0, 1]
     sage: DGroth[0,1].expand()
-    y[0]*xA[0, 0] + (-yA[1,1])*xA[-1, -1]
+    (-yA[1,1])*xA[-1, -1] + y[0]*xA[0, 0]
     sage: DGroth[3,2,3].isobaric_divided_difference(1)
     y[0]*GG[2, 2, 3]
     sage: DGroth[3,2,3].hat_isobaric_divided_difference(1)
@@ -218,9 +218,9 @@ class DoubleMultivariatePolynomialAlgebra_generic(MultivariatePolynomialAlgebra_
             There is a coercion between `D` and `D2`::
 
             sage: pol = x.an_element() * y.an_element(); pol
-            (y[1,2,3]+y[0,0,0]+2*y[1,0,0]+3*y[0,1,0])*x[1, 2, 3] + (y[1,2,3]+y[0,0,0]+2*y[1,0,0]+3*y[0,1,0])*x[0, 0, 0] + (2*y[1,2,3]+2*y[0,0,0]+4*y[1,0,0]+6*y[0,1,0])*x[1, 0, 0] + (3*y[1,2,3]+3*y[0,0,0]+6*y[1,0,0]+9*y[0,1,0])*x[0, 1, 0]
+            (y[0,0,0]+3*y[0,1,0]+2*y[1,0,0]+y[1,2,3])*x[0, 0, 0] + (3*y[0,0,0]+9*y[0,1,0]+6*y[1,0,0]+3*y[1,2,3])*x[0, 1, 0] + (2*y[0,0,0]+6*y[0,1,0]+4*y[1,0,0]+2*y[1,2,3])*x[1, 0, 0] + (y[0,0,0]+3*y[0,1,0]+2*y[1,0,0]+y[1,2,3])*x[1, 2, 3]
             sage: A2(pol)
-            (x[1,2,3]+x[0,0,0]+2*x[1,0,0]+3*x[0,1,0])*y[1, 2, 3] + (x[1,2,3]+x[0,0,0]+2*x[1,0,0]+3*x[0,1,0])*y[0, 0, 0] + (2*x[1,2,3]+2*x[0,0,0]+4*x[1,0,0]+6*x[0,1,0])*y[1, 0, 0] + (3*x[1,2,3]+3*x[0,0,0]+6*x[1,0,0]+9*x[0,1,0])*y[0, 1, 0]
+            (x[0,0,0]+3*x[0,1,0]+2*x[1,0,0]+x[1,2,3])*y[0, 0, 0] + (3*x[0,0,0]+9*x[0,1,0]+6*x[1,0,0]+3*x[1,2,3])*y[0, 1, 0] + (2*x[0,0,0]+6*x[0,1,0]+4*x[1,0,0]+2*x[1,2,3])*y[1, 0, 0] + (x[0,0,0]+3*x[0,1,0]+2*x[1,0,0]+x[1,2,3])*y[1, 2, 3]
 
         But this coercion doesn't allow for operations including polynomials from both ``A`` and ``A2`` as the coercion
         only exists between abstract polynomial rings but not between the concrete bases : sage coercion system
@@ -339,7 +339,7 @@ class Finite_rank_double_bases(Category):
                 sage: pol = x[1,0,0] * y[1,2,3]; pol
                 (y[1,2,3])*x[1, 0, 0]
                 sage: pol.change_coeffs_bases(AY.schubert_basis())
-                (Yy[1,2,3]-Yy[2,1,3]-Yy[1,3,2]+Yy[3,1,2]+Yy[2,3,1]-Yy[3,2,1]+Yy[4,1,1])*x[1, 0, 0]
+                (Yy[1,2,3]-Yy[1,3,2]-Yy[2,1,3]+Yy[2,3,1]+Yy[3,1,2]-Yy[3,2,1]+Yy[4,1,1])*x[1, 0, 0]
 
             """
             return sum( [ self.parent().term(x,new_base(y)) for (x,y) in self ] )
@@ -369,9 +369,9 @@ class Finite_rank_double_bases(Category):
                 sage: from multipolynomial_bases import MultivariatePolynomialAlgebra
                 sage: A.<x,y> = MultivariatePolynomialAlgebra(QQ)
                 sage: pol = A.an_element(); pol
-                y[0]*x[1, 2, 3] + y[0]*x[0, 0, 0] + 2*y[0]*x[1, 0, 0] + 3*y[0]*x[0, 1, 0]
+                y[0]*x[0, 0, 0] + 3*y[0]*x[0, 1, 0] + 2*y[0]*x[1, 0, 0] + y[0]*x[1, 2, 3]
                 sage: pol.swap_coeffs_elements()
-                (x[1,2,3]+x[0,0,0]+2*x[1,0,0]+3*x[0,1,0])*y[0]
+                (x[0,0,0]+3*x[0,1,0]+2*x[1,0,0]+x[1,2,3])*y[0]
             """
             inversed_ring = self.inversed_ring()
             coeffs_ring = inversed_ring.coeffs_ring()
@@ -405,13 +405,13 @@ class DoubleSchubertBasis(LinearBasisOnVectors):
         sage: DSchub[0,1]
         y[0]*YY[0, 1]
         sage: DSchub[0,1].expand()
-        y[0]*xA[1, 0] + y[0]*xA[0, 1] + (-yA[0,1]-yA[1,0])*xA[0, 0]
+        (-yA[0,1]-yA[1,0])*xA[0, 0] + y[0]*xA[0, 1] + y[0]*xA[1, 0]
         sage: DSchub[0,1]^2
-        y[0]*YY[0, 2] + y[0]*YY[1, 1] + (-yA[0,1,0]+yA[0,0,1])*YY[0, 1]
+        (yA[0,0,1]-yA[0,1,0])*YY[0, 1] + y[0]*YY[0, 2] + y[0]*YY[1, 1]
         sage: DSchub(x[0,1])
-        y[0]*YY[0, 1] + (-y[0])*YY[1, 0] + (yA[0,1])*YY[0, 0]
+        (yA[0,1])*YY[0, 0] + y[0]*YY[0, 1] + (-y[0])*YY[1, 0]
         sage: DSchub(y[0,1]*x[0,1])
-        (y[0,1])*YY[0, 1] + (-y[0,1])*YY[1, 0] + (yA[0,2])*YY[0, 0]
+        (yA[0,2])*YY[0, 0] + (y[0,1])*YY[0, 1] + (-y[0,1])*YY[1, 0]
         sage: DSchub(y[0,1])
         (y[0,1])*YY[0, 0]
 
@@ -465,7 +465,7 @@ class DoubleGrothendieckBasis(LinearBasisOnVectors):
         sage: DGroth[0,1]
         y[0]*GG[0, 1]
         sage: DGroth[0,1].expand()
-        y[0]*xA[0, 0] + (-yA[1,1])*xA[-1, -1]
+        (-yA[1,1])*xA[-1, -1] + y[0]*xA[0, 0]
         sage: DGroth[3,2,3].isobaric_divided_difference(1)
         y[0]*GG[2, 2, 3]
         sage: DGroth[3,2,3].hat_isobaric_divided_difference(1)
